@@ -9,7 +9,7 @@ from flockai.utils.string_generator import StringGenerator
 from flockai.models.devices.device_enums import EnableableDevice, NonEnableableDevice, MotorDevice
 from flockai.utils.intensive_thread import IntensiveThread
 import numpy as np
-
+import json
 
 class KeyboardMavic2DJI(KeyboardControlledDrone):
     """
@@ -39,6 +39,9 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
         :return: None
         """
 
+        if 5.0 - (self.getTime() % 5.0) != 0:
+            return 0
+
         total_time = 0
         probe_alive_time = self.probe.get_metric('ProbeAliveTimeMetric')
 
@@ -48,7 +51,9 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
                 return 0
             f_emitter = self.devices[emitter]['device']
             t1 = probe_alive_time.get_val()
-            f_emitter.send(msg.encode('utf-8'))
+            message = json.dumps(msg)
+            f_emitter.send(message.encode('utf-8'))
+
             t2 = probe_alive_time.get_val()
             total_time += t2 - t1
 
